==> haskell-aeson-qq-0.8.2-131-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-5KiRTbaWwzl53H9SkOwjvm
key: aeson-qq-0.8.2-5KiRTbaWwzl53H9SkOwjvm
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: 41c16cdfecdc56c65ec8356818ca16dd
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-5KiRTbaWwzl53H9SkOwjvm
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    haskell-src-meta-0.8.2-5ea07ASoRKFDEvaGsf0Tdo parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.2-135-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-Jw6HywNZL3rE22PhxkXqgc
key: aeson-qq-0.8.2-Jw6HywNZL3rE22PhxkXqgc
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: be022276d536d720d48681836890f52b
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-Jw6HywNZL3rE22PhxkXqgc
depends:
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    haskell-src-meta-0.8.2-KZb3g4f7nfRCqb0JV0UdRL parsec-3.1.13.0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b template-haskell-2.14.0.0
    text-1.2.3.1 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
